##  Exporting Diagrams From SAP LeanIX to Lucidchart
Exporting a diagram creates a public copy of the diagram in the SAP LeanIX workspace with the following naming convention: “ _Lucidchart export of OriginalReportName_ ”. This copy can only be edited in Lucidchart, providing similar capabilities as in SAP LeanIX for accurately representing the enterprise architecture landscape.
To export diagrams from SAP LeanIX to Lucidchart, follow these steps:
  1. Open the diagram you need to export.
  2. From the menu in the top right corner, select Export.
  3. Select Lucidchart Document. The diagram opens in Lucidchart.
![Exporting Diagrams From SAP LeanIX to Lucidchart](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e42157a44101499d1b716d158e74e_LowRes.png)
Exporting Diagrams From SAP LeanIX to Lucidchart
